@@ -1,10 +1,10 @@
 from zerohash.zerohash_object import ZerohashObject
 
 
-class APIResource:
+class APIResource(ZerohashObject):
     @classmethod
     def retrieve(cls, id, **kwargs):
-        instance = cls(id, *kwargs)
+        instance = cls(id, **kwargs)
         instance.refresh()
         return instance
 
