@@ -5,6 +5,9 @@ class ZerohashObject(dict):
     def __init__(self, id=None, credentials=None, **params):
         super().__init__()
 
+        self._unsaved_values = set()
+        self._transient_values = set()
+
         for k, v in params.items():
             self.__setattr__(k, v)
 
@@ -12,6 +15,22 @@ class ZerohashObject(dict):
         if id:
             self["id"] = id
 
+    def __setattr__(self, k, v):
+        if k[0] == "_" or k in self.__dict__:
+            return super().__setattr__(k, v)
+        self[k] = v
+        return None
+
+    def __getattr__(self, k):
+
+        if k[0] == "_":
+            raise AttributeError(k)
+
+        try:
+            return self[k]
+        except KeyError as ke:
+            raise AttributeError(*ke.args)
+
     @classmethod
     def construct_from(cls, values, credentials):
         instance = cls(values.get("id"), credentials=credentials)
@@ -31,8 +50,12 @@ class ZerohashObject(dict):
 
         # Any values not set in values will be cleared/removed from the object returned after refresh
         removed = set(self.keys()) - set(values)
+        self._transient_values = self._transient_values | removed
+        self._unsaved_values = set()
 
-        # self._transient_values = self._transient_values - set(values)
+        self.clear()
+
+        self._transient_values = self._transient_values - set(values)
 
         for k, v in values.items():
             super().__setitem__(k, util.convert_to_zerohash_object(v, credentials))
